import React, { useState, useEffect } from 'react';
import { Form, Input, Button, Icon, Select, Tabs, Radio, DatePicker, message, Upload } from 'antd';
import { FormattedMessage } from 'umi-plugin-react/locale';
import styles from '../style/GoodsList.less';
import apis from '../../services/apis';
import moment from 'moment';
import router from 'umi/router';
import BuildSelect from '../../components/SelectButton/BuildSelect'
import XForm, { FieldTypes } from '../../components/XForm';
import Wangedit from '../../components/Wangedit/Wangedit'
import request from '../../utils/request'
import yinhao from '../../assets/yinhao.png'
import ImageUploader from '../../components/XForm/ImageUpload';
import logo from '../../assets/logo.png';
import touxiang from '../../assets/touxiang.jpg';
import poster1 from '../../assets/poster1.png';
import poster2 from '../../assets/poster2.png';
import xiaochengxu from '../../assets/xiaochengxu.png';
import PosterCard from '../../components/Cards/PosterCard';

const { MonthPicker, RangePicker, WeekPicker } = DatePicker;
const { TextArea } = Input;

const formItemLayout = {
  labelCol: { span: 6 },
  wrapperCol: { span: 14 },
};

const cancelPage = () => {
  router.push({
    pathname: '/activity/ActivityList',
  });
}

const BasicForm = props => {
  const [isEnlist, setIsEnlist] = useState(1)
  const [activityStatus, setActivityStatus] = useState(1)
  const [disable, setDisable] = useState(false)

  const radioOnChange = e => {
    setIsEnlist(e.target.value)
  }

  const { dynamicId } = props

  // 查询详情
  const getDynamicData = dynamicId => {
    request({ ...apis.activity.details, params: { dynamicId } }).then((data) => {
      console.log(data)
      data.activityTime = [moment(data.startDate), moment(data.endDate)]
      data.signupTime = [moment(data.enlistStart), moment(data.enlistEnd)]

      setIsEnlist(data.isEnlist)
      setActivityStatus(data.activityStatus)
      setDisable(data.activityStatus === 0 ? true : false)
      props.form.setFieldsValue(data)
    })
  }

    // eslint-disable-next-line react-hooks/rules-of-hooks
    useEffect(() => {
      props.form.setFieldsValue({ isEnlist })
      if (dynamicId) {
        getDynamicData(dynamicId);
      }
    }, [])
 
  const handleSubmit = e => {
    e.preventDefault();
    props.form.validateFields((err, values) => {
      if (!err) {
        console.log('Received values of form: ', values);
        const { activityTime, signupTime } = values
        const [startDate, endDate] = activityTime
        values.startDate = moment(startDate).format('YYYY-MM-DD HH:mm');
        values.endDate = moment(endDate).format('YYYY-MM-DD HH:mm');
        if (signupTime) {
          const [enlistStart, enlistEnd] = signupTime
          values.enlistStart = moment(enlistStart).format('YYYY-MM-DD HH:mm');
          values.enlistEnd = moment(enlistEnd).format('YYYY-MM-DD HH:mm');
        }
        
        console.log('submit data --->', values)
        if (dynamicId) {
          values.dynamicId = dynamicId
          request({ ...apis.activity.update, data: values }).then(data => {
            message.info('保存成功')
            // router.go(-1)
          }).catch((err) => {
            message.info(err.msg || err.message)
          })
        } else {
          request({ ...apis.activity.add, data: { ...values } }).then((data) => {
            message.info('保存成功')
            router.push({
              pathname: '/activity/editActivity',
              query: {
                dynamicId: data.dynamicId,
              },
            });
            // router.go(-1)
          }).catch((err) => {
            message.info(err.msg || err.message)
          })
        }
      }
    });
  }

  const { getFieldDecorator } = props.form;
  return (
    <>
      <Form {...formItemLayout} onSubmit={handleSubmit}>
        <Form.Item label="所属项目">
        {getFieldDecorator('buildingId', {
          rules: [
            {
              required: true,
              message: '请选择所属项目',
            },
          ],
        })(<BuildSelect disabled={disable}/>)}
        </Form.Item>
        <Form.Item label="活动封面图1" help="建议图片尺寸：750px*420px，比例16:9,格式：jpg，用于活动列表">
          {getFieldDecorator('listImgUrl', {
          rules: [
            {
              required: true,
              message: '请选择活动封面图1',
            },
          ],
        })(<ImageUploader />)}
        </Form.Item>
        <Form.Item label="活动封面图2" help="建议图片尺寸：750*250，比例3:1，格式：jpg，用于：项目详情活动轮播">
          {getFieldDecorator('bannerListImg', {
          rules: [
            {
              required: true,
              message: '请选择活动封面图2',
            },
          ],
        })(<ImageUploader />)}
        </Form.Item>
        <Form.Item label="活动详情主图" help="建议图片尺寸：750*600px，比例5:4,格式：jpg，用于普通活动详情">
          {getFieldDecorator('imgUrl', {
          rules: [
            {
              required: true,
              message: '请选择活动详情主图',
            },
          ],
        })(<ImageUploader />)}
        </Form.Item>
        <Form.Item label="活动标题">
        {getFieldDecorator('title', {
          rules: [
            {
              required: true,
              message: '请输入活动标题',
            },
          ],
        })(<Input/>)}
        </Form.Item>
        <Form.Item label="活动时间">
        {getFieldDecorator('activityTime', {
          rules: [
            {
              required: true,
              message: '请选择活动时间',
            },
          ],
        })(<RangePicker format="YYYY-MM-DD HH:mm" disabled={activityStatus===0 ? true : false}/>)}
        </Form.Item>
        <Form.Item label="活动地点">
        {getFieldDecorator('address', {
          rules: [
            {
              required: true,
              message: '请输入活动地点',
            },
          ],
        })(<Input disabled={activityStatus===0 ? true : false}/>)}
        </Form.Item>
        <Form.Item label="活动人数">
        {getFieldDecorator('personNum', {
          rules: [
            {
              required: true,
              message: '请输入活动人数',
            },
          ],
        })(<Input type="number" disabled={activityStatus===0 ? true : false}/>)}
        </Form.Item>
        <Form.Item label="最大报名人数">
        {getFieldDecorator('maxEnlistByPerson', {
          rules: [
            {
              required: true,
              message: '请输入最大报名人数',
            },
          ],
        })(<Input type="number" disabled={activityStatus===0 ? true : false}/>)}
        </Form.Item>
        <Form.Item label="活动详情">
        {getFieldDecorator('desc')(<Wangedit />)}
        </Form.Item>
        <Form.Item label="报名时间">
          {getFieldDecorator('signupTime', {
            rules: [
              {
                required: true,
                message: '请选择报名时间',
              },
            ],
          })(<RangePicker format="YYYY-MM-DD HH:mm" disabled={activityStatus===0 ? true : false}/>)}
        </Form.Item>  
        <Form.Item label="权重">
        {getFieldDecorator('heavy', {
          rules: [
            {
              required: true,
              message: '请输入权重',
            },
          ],
        })(<Input type="number" style={{ width: 80}}/>)}<span style={{ marginLeft: 30, color:'grey'}}>数字越大越靠前</span>
        </Form.Item>
        <Form.Item wrapperCol={{ span: 12, offset: 8 }}>
          <Button type="primary" htmlType="submit">
            确认
          </Button>
          &nbsp;&nbsp;&nbsp;&nbsp;
          <Button onClick={() => cancelPage()}>
            取消
          </Button>
        </Form.Item>
      </Form>
    </>
  )
}

const Basic = Form.create({ name: 'BasicForm' })(BasicForm);

/**
 *
 *
 * @param {*} props
 * @returns
 */
const Edit = props => {
  const [tab, changeTab] = useState('basic')
  const { dynamicId } = props.location.query


  const Poster = (props) => {
    const [inputValue, changeInput] = useState('')
    const [textAreaValue, changeTextArea] = useState('')
    const [imgValue, changeImg] = useState('')
    const [posterId, setPosterId] = useState('')

    if (dynamicId) {
      console.log(dynamicId, 'dynamicId')
      useEffect(() => {
        request({ ...apis.activity.poster, params: { targetId: dynamicId, targetType: 'activity' } }).then((data) => {
          console.log(data, "2222")
          if (data.length > 0) {
            setPosterId(data[0].posterId)
            changeImg(data[0].posterImg)
            changeTextArea(data[0].posterDescription)
            changeInput(data[0].posterTitle)
          }
        }).catch((err) => {
          message.info(err.msg || err.message)
        })
        getMiniappName()
      }, [])
    }else{
      getMiniappName()
    }
    // 获取小程序名称
    const [miniappName, setMiniappName] = useState('')
    function getMiniappName() {
      request({ ...apis.building.getMiniappName }).then(res => {
        console.log(res, "0000000000000")
        setMiniappName(res)
      })
    }

    const submitPoster = () => {
      if (dynamicId) {
        if (posterId) {
          request({ ...apis.activity.updatePoster, urlData: { id: posterId }, data: { targetId: dynamicId, targetType: 'activity', posterImg: imgValue, posterTitle: inputValue, posterDescription: textAreaValue }, }).then((data) => {
            message.info("保存成功")
          }).catch((err) => {
            message.info(err.msg || err.message)
          })
        } else {
          request({ ...apis.activity.addPoster, data: { targetId: dynamicId, targetType: 'activity', posterImg: imgValue, posterTitle: inputValue, posterDescription: textAreaValue }, }).then((data) => {
            setPosterId(data.posterId)
            message.info("保存成功")
          }).catch((err) => {
            message.info(err.msg || err.message)
          })
        }
      } else {
        message.warn("请先保存基本信息数据")
      }
    }

    const changePoster = e => {
      console.log(e,"返回出来的数据")
    }

    return <div>
      <PosterCard onChange={changePoster}/>
      <Button type="primary" onClick={submitPoster} style={{ margin: '40px 40px 40px 30vw' }}> 确定</Button>
      <Button onClick={() => cancelPage()}>
        取消
      </Button>
    </div>

  }



  const Share = (props) => {
    const [inputValue, changeInput] = useState('')
    const [imgValue, changeImg] = useState('')
    const [shareContentId, setShareContentId] = useState('')

    if (dynamicId) {
      useEffect(() => {
        request({ ...apis.activity.shareContent, params: { targetId: dynamicId, targetType: 'activity' }, }).then((data) => {
          console.log(data, "2222")
          if (data.length > 0) {
            setShareContentId(data[0].shareContentId)
            changeImg(data[0].shareContentImg)
            changeInput(data[0].shareContentTitle)
          }
        }).catch((err) => {
          message.info(err.msg || err.message)
        })
      }, [])
    }

    const submitShare = () => {
      if (dynamicId) {
        if (shareContentId) {
          request({ ...apis.activity.updateShareContent, urlData: { id: shareContentId }, data: { targetId: dynamicId, shareContentType: 'activity', shareContentImg: imgValue, shareContentTitle: inputValue }, }).then((data) => {
            message.info("保存成功")
          }).catch((err) => {
            message.info(err.msg || err.message)
          })
        } else {
          request({ ...apis.activity.addShareContent, data: { targetId: dynamicId, shareContentType: 'activity', shareContentImg: imgValue, shareContentTitle: inputValue }, }).then((data) => {
            setShareContentId(data.shareContentId)
            message.info("保存成功")
          }).catch(err => {
            message.info(err.msg || err.message)
          })
        }
      } else {
        message.warn("请先保存基本信息数据")
      }
    }

    return <div style={{ padding: '20px' }}>
      <div style={{ display: 'flex', margin: '10px 0 40px 0', width: '100%' }}>
        <p style={{ minWidth: '200px', color: '#222', textAlign: 'right', margin: '0 30px 0 0' }}>分享模板</p>
        <div>
          <p style={{ display: 'flex', alignItems: 'center', fontSize: '14px', color: '#999', margin: '0', lineHeight: '0' }}><img src={logo} style={{ width: '22px', marginRight: '10px' }} />知与行互动</p>
          <p style={{ fontSize: '16px', color: '#222', fontWeight: '600', margin: '0' }}>{inputValue ? inputValue : '置业V客厅 精准获客平台'}</p>
          <img style={{ width: '200px', height: '140px' }} src={imgValue ? imgValue : poster2} alt="" />
        </div>
      </div>
      <div style={{ display: 'flex', alignItems: 'center', width: '100%' }}>
        <p style={{ minWidth: '200px', color: '#222', textAlign: 'right', margin: '0 30px 0 0' }}>分享标题</p>
        <Input placeholder="请输入分享标题" value={inputValue} onChange={e => changeInput(e.target.value)} />
      </div>
      <div style={{ display: 'flex', width: '100%', marginTop: '40px' }}>
        <p style={{ minWidth: '200px', color: '#222', textAlign: 'right', margin: '0 30px 0 0' }}>活动分享图</p>
        <ImageUploader value={imgValue} onChange={e => changeImg(e)} />
      </div>
      <p style={{ fontSize: '0.5vw', color: '#A9A9A9', marginLeft: '230px', marginTop: '20px' }}>建议图片尺寸：750*600px，比例5:4,格式：jpg，用于活动分享好友</p>
      <Button type="primary" htmlType="submit" onClick={submitShare} style={{ margin: '40px 40px 40px 220px' }}> 确定</Button>
      <Button onClick={() => cancelPage()}>
        取消
      </Button>
    </div>
  }

  return (
    <div>
      <div>
        <Radio.Group value={tab} buttonStyle="solid" onChange={e => changeTab(e.target.value)}>
          <Radio.Button value="basic">基本信息</Radio.Button>
          <Radio.Button value="poster">海报图片</Radio.Button>
          <Radio.Button value="share">分享设置</Radio.Button>
        </Radio.Group>
      </div>
      <div>
        {tab === 'basic' && <Basic dynamicId={dynamicId} />}
        {tab === 'poster' && <Poster />}
        {tab === 'share' && <Share />}
      </div>
    </div>
  );
}

export default Edit
